checkInternetConnectivity property

bool checkInternetConnectivity
getter/setter pair

Flag to enable/disable automatic internet connectivity monitoring.

When true, the controller will automatically listen to connectivity changes and update isConnected. When false, connectivity monitoring is disabled.

Default: true

Set to false in subclasses if connectivity monitoring is not needed:

class MyController extends RtBaseController {
  MyController() {
    checkInternetConnectivity = false;
  }
}

Implementation

bool checkInternetConnectivity = true;