SplashScreenVar mixin

Mixin providing splash screen configuration constants.

Contains settings for the application splash screen including background color, logo size, and animation parameters.

Mixin applications

Properties

animationDurationSeconds int
Duration of splash animation in seconds.
getter/setter pair
animationOpacity double
Final opacity value for splash animation (1.0 = fully opaque).
getter/setter pair
backgroundColor Color
Background color for the splash screen.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashLogoSize double
Size of the splash screen logo (200.0 logical pixels).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited