app/models/place_detail library
Classes
- AddressComponent
- Component of a place's address (e.g., street, city, postal code).
- Close
- Closing time information for a place.
- CurrentOpeningHours
- Current opening hours information for a place.
- Geometry
- Geographic location and viewport information for a place.
- Location
- Geographic coordinates (latitude and longitude).
- Open
- Opening time information for a place.
- OpeningHours
- Opening hours information for a place.
- Period
- Opening/closing time period for a specific day.
- Photo
- Photo information for a place.
- PlaceDetail
- Data model representing detailed information about a place from Google Places API.
- PlusCode
- Plus Code location identifier.
- Result
- Comprehensive place information from Google Places Details API.
- Review
- User review for a place.
- Viewport
- Recommended viewport for displaying a location on a map.