AddressComponent class
Component of a place's address (e.g., street, city, postal code).
Each address component has both long and short forms and is tagged with types indicating what part of the address it represents.
Example:
- longName: "California", shortName: "CA", types:
"administrative_area_level_1" - longName: "United States", shortName: "US", types:
"country"
Constructors
-
AddressComponent({String? longName, String? shortName, List<
String> ? types}) - Creates an AddressComponent instance.
-
AddressComponent.fromJson(Map<
String, dynamic> json) -
Creates an AddressComponent from JSON data.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- longName ↔ String?
-
Full form of the address component
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortName ↔ String?
-
Abbreviated form (e.g., "CA" for "California")
getter/setter pair
-
types
↔ List<
String> ? -
Types/categories of this component (e.g., "locality", "country")
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited