CurrentOpeningHours class

Current opening hours information for a place.

Includes whether the place is currently open, detailed opening/closing periods for each day, and human-readable weekday text.

Example weekdayText:

  • "Monday: 9:00 AM – 5:00 PM"
  • "Tuesday: 9:00 AM – 5:00 PM"

Constructors

CurrentOpeningHours({bool? openNow, List<Period>? periods, List<String>? weekdayText})
Creates a CurrentOpeningHours instance.
CurrentOpeningHours.fromJson(Map<String, dynamic> json)
Creates a CurrentOpeningHours from JSON data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
openNow bool?
Whether the place is currently open
getter/setter pair
periods List<Period>?
Detailed opening/closing periods for each day of the week
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weekdayText List<String>?
Human-readable opening hours for each weekday
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited