Open class

Opening time information for a place.

Includes the date, day of week (0=Sunday, 6=Saturday), and time in HHMM format. Mirror of Close class for opening time data.

Constructors

Open({String? date, int? day, String? time})
Creates an Open instance.
Open.fromJson(Map<String, dynamic> json)
Creates an Open from JSON data.
factory

Properties

date String?
Date in YYYY-MM-DD format
getter/setter pair
day int?
Day of week (0=Sunday, 1=Monday, ..., 6=Saturday)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String?
Time in HHMM 24-hour format (e.g., "0900" for 9:00 AM)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited