Period class

Opening/closing time period for a specific day.

Contains both open and close times with day, date, and time information.

Constructors

Period({Close? close, Open? open})
Creates a Period instance.
Period.fromJson(Map<String, dynamic> json)
Creates a Period from JSON data.
factory

Properties

close Close?
Closing time details
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
open Open?
Opening time details
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited