onScaleChanged property

void Function(double) onScaleChanged
final

Callback invoked when the scale changes during zoom/pan interaction.

Called both during interaction updates and at the end of interactions, receiving the current scale factor as a parameter.

Implementation

final void Function(double) onScaleChanged;