errorWidget property
Optional custom error widget to display when errors occur.
Set this widget to provide a custom error UI that will be displayed
by RtBaseView when an error state is detected. If null, the view
will use its default error widget.
Example:
@override
void onInit() {
super.onInit();
errorWidget = CustomErrorWidget(
onRetry: () => loadData(),
);
}
See also:
- RtBaseView which uses this widget for error state rendering
Implementation
Widget? errorWidget;