totalCount property
Reactive total count of available items.
Represents the total number of items available from the data source, useful for displaying pagination info or determining if more data is available.
Implementation
RxInt totalCount = 0.obs;