BottomSheetHeaderConst mixin
Mixin providing bottom sheet header styling constants.
Contains configuration for bottom sheet headers including border radius, padding, dimensions, and close button styling.
- Mixin applications
Properties
- bottomSheetContainerBorderRadius ↔ BorderRadius
-
Border radius for bottom sheet container (rounded top corners).
getter/setter pair
- bottomSheetImageClose ↔ Icon
-
Icon widget for bottom sheet close button.
getter/setter pair
- btnClosePadding ↔ EdgeInsets
-
Padding for the close button in bottom sheets.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerHeight ↔ double
-
Height of the bottom sheet header: 70 logical pixels.
getter/setter pair
- headerPadding ↔ EdgeInsets
-
Padding for bottom sheet header content.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited