app/models/place_auto_complete library
Classes
- MatchedSubstring
- Represents a substring in the prediction that matches the user's input.
- PlaceAutoComplete
- Data model representing the response from Google Places Autocomplete API.
- StructuredFormatting
- Structured breakdown of a place prediction into main and secondary text.
- Term
- Represents an individual term/word in a place prediction.