Photo class
Photo information for a place.
Contains dimensions, reference ID, and HTML attributions for a place photo. Use photoReference to fetch the actual image from Google Places Photo API.
Example:
final photo = place.photos?.first;
final url = 'https://maps.googleapis.com/maps/api/place/photo'
'?maxwidth=${photo?.width}'
'&photoreference=${photo?.photoReference}'
'&key=$apiKey';
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int?
-
Photo height in pixels
getter/setter pair
-
htmlAttributions
↔ List<
String> ? -
HTML attributions that must be displayed
getter/setter pair
- photoReference ↔ String?
-
Reference ID for fetching the photo
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width ↔ int?
-
Photo width in pixels
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited