PlusCode class
Plus Code location identifier.
Plus Codes are short codes that can be used as digital addresses where street addresses don't exist. Contains both compound (local) and global codes.
Example:
- compoundCode: "8Q7X+5R San Francisco, CA, USA"
- globalCode: "849V8Q7X+5R"
Learn more: https://plus.codes/
Constructors
Properties
- compoundCode ↔ String?
-
Compound code including locality (e.g., "8Q7X+5R San Francisco, CA")
getter/setter pair
- globalCode ↔ String?
-
Global code usable anywhere (e.g., "849V8Q7X+5R")
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited