Result class
Comprehensive place information from Google Places Details API.
Contains all available data about a specific place including:
- Basic info: name, address, phone number
- Business details: hours, delivery, dining options
- Location: coordinates, geometry
- Media: photos, icon
- Reviews and ratings
- Address components
This is the main data class for place details.
Constructors
-
Result({List<
AddressComponent> ? addressComponents, String? adrAddress, String? businessStatus, bool? curbsidePickup, CurrentOpeningHours? currentOpeningHours, bool? delivery, bool? dineIn, String? formattedAddress, String? formattedPhoneNumber, Geometry? geometry, String? icon, String? iconBackgroundColor, String? iconMaskBaseUri, String? internationalPhoneNumber, String? name, OpeningHours? openingHours, List<Photo> ? photos, String? placeId, PlusCode? plusCode, int? priceLevel, double? rating, String? reference, bool? reservable, List<Review> ? reviews}) - Creates a Result instance with all place details.
-
Result.fromJson(Map<
String, dynamic> json) -
Creates a Result from Google Places API JSON response.
factory
Properties
-
addressComponents
↔ List<
AddressComponent> ? -
Structured address components (street, city, country, etc.)
getter/setter pair
- adrAddress ↔ String?
-
Address in adr microformat
getter/setter pair
- businessStatus ↔ String?
-
Business operational status (e.g., "OPERATIONAL", "CLOSED_TEMPORARILY")
getter/setter pair
- curbsidePickup ↔ bool?
-
Whether curbside pickup is available
getter/setter pair
- currentOpeningHours ↔ CurrentOpeningHours?
-
Current opening hours information
getter/setter pair
- delivery ↔ bool?
-
Whether delivery service is available
getter/setter pair
- dineIn ↔ bool?
-
Whether dine-in service is available
getter/setter pair
- formattedAddress ↔ String?
-
Human-readable full address
getter/setter pair
- formattedPhoneNumber ↔ String?
-
Formatted phone number with country code
getter/setter pair
- geometry ↔ Geometry?
-
Geographic location and viewport
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ String?
-
URL to the place type icon
getter/setter pair
- iconBackgroundColor ↔ String?
-
Background color for the icon
getter/setter pair
- iconMaskBaseUri ↔ String?
-
Base URI for the icon mask
getter/setter pair
- internationalPhoneNumber ↔ String?
-
Phone number in international format
getter/setter pair
- name ↔ String?
-
Name of the place
getter/setter pair
- openingHours ↔ OpeningHours?
-
Opening hours information
getter/setter pair
-
photos
↔ List<
Photo> ? -
Array of photos of the place
getter/setter pair
- placeId ↔ String?
-
Unique identifier for the place
getter/setter pair
- plusCode ↔ PlusCode?
-
Plus Code location reference
getter/setter pair
- priceLevel ↔ int?
-
Price level (0-4, where 0 is free and 4 is very expensive)
getter/setter pair
- rating ↔ double?
-
Overall rating (0.0 to 5.0)
getter/setter pair
- reference ↔ String?
-
Deprecated reference value
getter/setter pair
- reservable ↔ bool?
-
Whether reservations are accepted
getter/setter pair
-
reviews
↔ List<
Review> ? -
User reviews of the place
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited