Viewport class
Recommended viewport for displaying a location on a map.
Defines a rectangular bounding box using northeast and southwest corners. Used to frame the map appropriately when showing a place.
Example:
final viewport = Viewport(
northeast: Location(lat: 37.8, lng: -122.3),
southwest: Location(lat: 37.7, lng: -122.5),
);
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- northeast ↔ Location?
-
Northeast corner of the viewport
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- southwest ↔ Location?
-
Southwest corner of the viewport
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited